pub struct Handle<L, S> { /* private fields */ }Expand description
Allows modifying the state of an associated reloadable layer.
Implementations
Sourceimpl<L, S> Handle<L, S>
impl<L, S> Handle<L, S>
Sourcepub fn reload_with(&self, f: impl FnOnce(&L) -> L) -> Result<(), Error>
pub fn reload_with(&self, f: impl FnOnce(&L) -> L) -> Result<(), Error>
Replaces the active layer with a new one.
The closure provides a reference to the active layer so if the layer implements Clone, it
can be constructed that way and then modified in place.