Layer

Struct Layer 

pub struct Layer<L, S> { /* private fields */ }
Wraps another type implementing tracing_subscriber::layer::Layer or tracing_subscriber::layer::Filter, allowing it to be modified dynamically at runtime.

The inner value is pinned at construction time so its address is stable. This makes it safe to return raw pointers from Layer::downcast_raw.

Implementations

Source

impl<L, S> Layer<L, S>

pub fn new(inner: L) -> (Self, Handle<L, S>)

Wraps the given value, returning a Layer and a Handle that allows the inner value to be replaced at runtime.

pub fn new_with_routing( inner: L, span_routing: ReloadRouting, ) -> (Self, Handle<L, S>)

Wraps the given value with a specific span routing strategy, returning a Layer and a Handle that allows the inner value to be replaced at runtime.

pub fn handle(&self) -> Handle<L, S>

Returns a Handle that can be used to replace the wrapped Layer.