pub struct ReloadSubscriber<S>where
S: 'static,{ /* private fields */ }Expand description
This is a fake subscriber that should not be constructed by user-code.
It exists only for this crate’s internal purposes but must be public because it may appear as a
generic parameter of other crates’ structs and traits. Most notably in
Layer<S>.